%define major     1
%define libname   %mklibname mxml %{major}
%define develname %mklibname -d mxml

Name:           mxml
Version:        3.0
Release:        %mkrel 1
Summary:        Miniature XML development library
License:        ASL 2.0 with exception
Group:          System/Libraries
URL:            http://michaelrsweet.github.io/mxml/
Source0:        https://github.com/michaelrsweet/mxml/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  gcc

%description
Mini-XML is a small XML parsing library that you can use to read XML and
XML-like data files in your application without requiring large non-standard
libraries.  Mini-XML provides the following functionality:

- Reading of UTF-8 and UTF-16 and writing of UTF-8 encoded  XML files and
  strings.
- Data is stored in a linked-list tree structure, preserving  the XML data
  hierarchy.
- Supports arbitrary element names, attributes, and attribute values with no
  preset limits, just available memory.
- Supports integer, real, opaque ("cdata"), and text data types in "leaf"
  nodes.
- Functions for creating and managing trees of data.
- "Find" and "walk" functions for easily locating and navigating trees of data.

Mini-XML doesn't do validation or other types of processing on the data based
upon schema files or other sources of definition information, nor does it
support character entities other than those required by the XML specification.
#-------------------------------------------------------------------------------

%package -n %{libname}
Summary:        Miniature XML development library
Group:          System/Libraries

%description -n %{libname}
Mini-XML is a small XML parsing library that you can use to read XML and
XML-like data files in your application without requiring large non-standard
libraries.  Mini-XML provides the following functionality:

- Reading of UTF-8 and UTF-16 and writing of UTF-8 encoded  XML files and
  strings.
- Data is stored in a linked-list tree structure, preserving  the XML data
  hierarchy.
- Supports arbitrary element names, attributes, and attribute values with no
  preset limits, just available memory.
- Supports integer, real, opaque ("cdata"), and text data types in "leaf"
  nodes.
- Functions for creating and managing trees of data.
- "Find" and "walk" functions for easily locating and navigating trees of data.

Mini-XML doesn't do validation or other types of processing on the data based
upon schema files or other sources of definition information, nor does it
support character entities other than those required by the XML specification.
#-------------------------------------------------------------------------------

%package -n %{develname}
Summary:        Shared library and header files for the Miniature XML development library
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       libmxml-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %mklibname -d mxml 1

%description -n %{develname}
This package contains the shared mxml library and its header files.

#-------------------------------------------------------------------------------

%prep

%setup -q

%build
%configure2_5x \
    --enable-shared
%make_build

%install
%make_install BUILDROOT=%{buildroot}

# Configuring with --disable-static doesn't work, so let's just delete
# the .a file by hand.
find %{buildroot} -name '*.a' -delete

mv %{buildroot}%{_datadir}/doc/mxml installed-docs

rm -rf %{buildroot}%{_mandir}/cat*

%files -n %{libname}
%doc CHANGES.md README.md doc/*.html
%license LICENSE
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%doc installed-docs/*
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/mxml.pc
%{_mandir}/man3/*


%changelog
* Fri Mar 29 2019 daviddavid <daviddavid> 3.0-1.mga6
+ Revision: 1381172
- new version: 3.0, fixes CVE-2018-2000[45] and CVE-2018-2059[23] (mga#24583)
- devel subpkg require library subpkg

* Sun Apr 02 2017 mrambo3501 <mrambo3501> 2.10-1.mga6
+ Revision: 1095610
- version 2.10 fixes CVE-2016-4570 and CVE-2016-4571
- removed one no longer supported configure option
- changed a couple of macros in spec to current settings

* Fri Feb 12 2016 umeabot <umeabot> 2.8-2.mga6
+ Revision: 956191
- Mageia 6 Mass Rebuild

* Sat Jul 25 2015 tv <tv> 2.8-1.mga6
+ Revision: 857450
- new release

* Wed Oct 15 2014 umeabot <umeabot> 2.7-6.mga5
+ Revision: 749143
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.7-5.mga5
+ Revision: 727419
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.7-4.mga5
+ Revision: 682712
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2.7-3.mga4
+ Revision: 518069
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.7-2.mga3
+ Revision: 360559
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Oct 18 2012 fwang <fwang> 2.7-1.mga3
+ Revision: 307866
- update file list
- new version 2.7

* Sun May 01 2011 shikamaru <shikamaru> 2.6-1.mga1
+ Revision: 94106
- Clean spec
- kill buildroot
- reorder tags and retab
- add separators between subpackages to improve readability
- use braces around macros
- remove useless test before cleaning buildroot
- imported package mxml


* Mon Jun 08 2009 Götz Waschk <waschk@mandriva.org> 2.6-1mdv2010.0
+ Revision: 383920
- new version
- fix source URL

* Tue Jul 29 2008 Thierry Vignaud <tv@mandriva.org> 2.5-3mdv2009.0
+ Revision: 253406
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu Jan 31 2008 Götz Waschk <waschk@mandriva.org> 2.5-1mdv2008.1
+ Revision: 160646
- new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Nov 24 2007 Götz Waschk <waschk@mandriva.org> 2.4-1mdv2008.1
+ Revision: 111769
- new version

* Mon Oct 22 2007 Götz Waschk <waschk@mandriva.org> 2.3-1mdv2008.1
+ Revision: 101117
- new devel name
- fix URL
- fix license

  + Thierry Vignaud <tv@mandriva.org>
    - replace %%{_datadir}/man by %%{_mandir}!

* Sat Apr 28 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.3-1mdv2008.0
+ Revision: 18974
- new version
- drop P0
- use macros
- remove rpath
- drop provides and obsoletes from -devel


* Tue Oct 24 2006 Oden Eriksson <oeriksson@mandriva.com> 2.2.2-2mdv2007.0
+ Revision: 72133
- forgot to add the patch...
- new major
- make it a shared lib
- Import mxml

* Mon May 29 2006 Götz Waschk <waschk@mandriva.org> 2.2.2-1mdv2007.0
- Rebuild

* Thu May 26 2005 Götz Waschk <waschk@mandriva.org> 2.2.2-1mdk
- New release 2.2.2

* Sat Apr 16 2005 Götz Waschk <waschk@linux-mandrake.com> 2.2-1mdk
- source URL
- New release 2.2

* Mon Jul 19 2004 Götz Waschk <waschk@linux-mandrake.com> 2.0-1mdk
- initial package

